==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GeographicMarkerSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMarkerSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicMarkerSeriesBaseDescriptionMetadata, _super);
    function GeographicMarkerSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMarkerSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicMarkerSeriesBaseDescriptionMetadata.a == null) {
            GeographicMarkerSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMarkerSeriesBaseDescriptionMetadata.c(GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicMarkerSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicMarkerSeriesBaseDescriptionMetadata.a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.c(a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.b(a);
        a.z("GeographicMarkerSeriesBase", GeographicMarkerSeriesBaseDescriptionMetadata.a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.$t = markType(GeographicMarkerSeriesBaseDescriptionMetadata, 'GeographicMarkerSeriesBaseDescriptionMetadata');
    GeographicMarkerSeriesBaseDescriptionMetadata.a = null;
    return GeographicMarkerSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicMarkerSeriesBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GeographicMarkerSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMarkerSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicMarkerSeriesBaseDescriptionMetadata, _super);
    function GeographicMarkerSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMarkerSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicMarkerSeriesBaseDescriptionMetadata.a == null) {
            GeographicMarkerSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMarkerSeriesBaseDescriptionMetadata.c(GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(GeographicMarkerSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(GeographicMarkerSeriesBaseDescriptionMetadata.a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.c(a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.b(a);
        a.ab("GeographicMarkerSeriesBase", GeographicMarkerSeriesBaseDescriptionMetadata.a);
    };
    GeographicMarkerSeriesBaseDescriptionMetadata.$t = markType(GeographicMarkerSeriesBaseDescriptionMetadata, 'GeographicMarkerSeriesBaseDescriptionMetadata');
    GeographicMarkerSeriesBaseDescriptionMetadata.a = null;
    return GeographicMarkerSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicMarkerSeriesBaseDescriptionMetadata };
